{% extends "kegadmin/base.html" %}
{% load kegweblib %}
{% load crispy_forms_tags %}

{% block pagetitle %}Kegbot Admin{% endblock %}

{% block kegadmin-main %}
<h2>General Settings</h2>

<div class="well">
  <form action="" method="POST">{% csrf_token %}
    {{ settings_form|crispy }}
    <div class="actions">
      <button type="submit" class="btn btn-primary">Update Settings</button>
    </div>
  </form>
</div>

{% endblock %}
