<div class="kb-tapbox-image">
  {% if keg.type.GetImage %}
    <img src="{{ keg.type.GetImage.thumbnail.url }}">
  {% else %}
    <img src="{{ STATIC_URL }}images/kegbot-unknown-square.png">
  {% endif %}
</div>

