{% extends "base.html" %}
{% load kegweblib %}

{% block title %}kegbot account{% endblock %}

{% block content %}
<div class="row">
  <div class="span2">
    <ul class="nav nav-pills nav-stacked" data-pills="pills">
      {% navitem kb-account-main "Account Main" exact %}
      {% navitem password_change "Password" %}
      {% navitem account-mugshot "Mugshot" %}
      {% navitem account-connections "Connections" %}
      {% if USE_FACEBOOK %}
      {% navitem fb-account-settings "Facebook" %}
      {% endif %}
    </ul>
  </div>

  <div class="span8">
    {% block kb-account-main %}{% endblock %}
  </div>
</div>

{% endblock %}
