{% extends "base.html" %}

{% block title %}all drinkers{% endblock %}

{% block content %}
<div class="content">
   <ul>
      {% for drinker in drinker_list %}
      <li> {{ drinker }}
      {% endfor %}
   </ul>
</div>
{% endblock %}
