{% extends "base.html" %}
{% load kegweblib %}

{% block title %}Logged Out{% endblock %}
{% block pagetitle %}Logged Out{% endblock %}

{% block content %}
  You hav been logged out.  So long!
{% endblock %}
