<div class="contenthead">
  {{ page.title }}
</div>
<div class="content">
{% ifequal page.markup "markdown" %}
  {% load markup %}
  {{ page.content|markdown }}
{% else %}
  {% ifequal page.markup "html" %}
    {{ page.content|safe }}
  {% else %}
    {{ page.content|linebreaks|urlize }}
  {% endifequal %}
{% endifequal %}
</div>


