{% load kegweblib %}
<div class="kb-drink-box">
  <div class="kb-drink-box-mugshot">
    {% mugshot_box drink.user 48 %}
  </div>
  <div class="kb-drink-box-details">
    <div class="kb-drink-box-details-headline">
      {% if drink.user %}<a href="{% url kb-drinker kbsite.url drink.user.username %}">{{drink.user.username}}</a> {% else %} {{guest_info.name}}{% endif %} poured
      {% volume drink.volume_ml %}
    </div>
    <div class="kb-event-box-info">
      <a href="{% url kb-drink kbsite.url drink.seqn %}">drink {{drink.seqn}}</a>
      {% if drink.keg %} from <a href="{% url kb-keg kbsite.url drink.keg.seqn %}">{{drink.keg.type.name}}</a>{% endif %}
    </div>
  </div>
  <div class="kb-event-box-dateline">
    {% timeago drink.time %}
  </div>
  <div class="clear"></div>
</div>
